# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added

- v0.5 Added generic classes for arbitrary number of labels and classifiers.
       These are ntqr.raxioms.MAxiomsIdeal and
       ntqr.evaluations.MLabelResponseSimplexes

### Changed

### Removed

## [0.5.1] - 2025-04-25

### Added

### Fixed

- Incorrect processing of labels in ntqr.raxioms.MAxiomsIdeal._m_two_ideal.

### Changed

### Removed


